@@ -111,6 +111,8 @@ cp -r /usr/share/kservicetypes5                           ./usr/share
 cp -r /usr/share/kxmlgui5                                 ./usr/share
 cp -r /usr/share/kf5                                      ./usr/share
 cp -r /usr/share/solid                                    ./usr/share
+cp -r /usr/share/icu                                      ./usr/share
+cp -r /usr/share/mime                                     ./usr/share
 
 # depending of OpenCV version installed, data directory is not the same.
 cp -r /usr/share/OpenCV                                   ./usr/share  || true
@@ -145,12 +147,6 @@ echo -e "------------- Copy sane backends\n"
 cp -r /usr/${LIBSUFFIX}/sane                            ./usr/lib
 cp -r /etc/sane.d                                       ./usr/etc
 
-echo -e "------------- Copy ImageMagick codecs\n"
-
-# NOTE: even with 64 bits, magick .so files are stored in /usr/lib
-
-cp -r /usr/lib64/ImageMagick*/modules*                  ./usr/lib
-
 echo -e "------------- Copy I18n\n"
 
 # Qt translations files
@@ -467,6 +463,12 @@ if [[ $DK_VERSION != v* ]] ; then
     # with non-official release version, use build time-stamp as sub-version string.
     DK_SUBVER="-`cat $ORIG_WD/data/BUILDDATE.txt`"
 
+else
+
+    # with official release version, disable upload to KDE server, as this break check for new version function.
+    echo -e "Official release version detected, upload is disabled.\n"
+    DK_UPLOAD = 0
+
 fi
 
 if [[ "$ARCH" = "x86_64" ]] ; then
