@@ -66,6 +66,8 @@ cmake $ORIG_WD/../3rdparty \
        -DMACOSX_DEPLOYMENT_TARGET=$OSX_MIN_TARGET \
        -Wno-dev
 
+cmake --build . --config RelWithDebInfo --target ext_heif   -- -j$CPU_CORES
+cp $DOWNLOAD_DIR/heif_manifest.txt $ORIG_WD/data/
 cmake --build . --config RelWithDebInfo --target ext_exiv2   -- -j$CPU_CORES
 cp $DOWNLOAD_DIR/exiv2_manifest.txt $ORIG_WD/data/
 cmake --build . --config RelWithDebInfo --target ext_qtav    -- -j$CPU_CORES
