@@ -90,8 +90,6 @@ lib/mariadb-10.5/bin/mysqladmin \
 lib/mariadb-10.5/bin/mysqltest \
 lib/mariadb-10.5/mysql/*.dylib \
 lib/mariadb-10.5/plugin/*.so \
-lib/ImageMagick*/modules-Q16/coders/*.so \
-lib/ImageMagick*/modules-Q16/filters/*.so \
 bin/kbuildsycoca5 \
 bin/solid-hardware5 \
 libexec/qt5/plugins/imageformats/*.dylib \
@@ -609,6 +607,12 @@ if [[ $DK_VERSION != v* ]] ; then
     # with non-official release version, use build time-stamp as sub-version string.
     DK_SUBVER="-`cat $ORIG_WD/data/BUILDDATE.txt`"
 
+else
+
+    # with official release version, disable upload to KDE server, as this break check for new version function.
+    echo -e "Official release version detected, upload is disabled.\n"
+    DK_UPLOAD = 0
+
 fi
 
 TARGET_INSTALLER=digiKam-$DKRELEASEID$DK_SUBVER-MacOS-x86-64$DEBUG_SUF.pkg
