@@ -95,29 +95,37 @@ else
     git checkout $MXE_GIT_REVISION
 fi
 
+#################################################################################################
+
+if [[ $MXE_GCC_VERSION != "default" ]]; then
+
+    # Use a specific gcc version with MXE
+    echo -e "\n"
+    echo "---------- Building cross-compiler for MXE"
+    make MXE_TARGETS=$MXE_BUILD_TARGETS cc MXE_PLUGIN_DIRS="plugins/gcc$MXE_GCC_VERSION"
+
+    echo -e "\n"
+    echo "---------- Building digiKam low level dependencies with GCC version $MXE_GCC_VERSION"
+
+    # Switch to a more recent gcc version
+    echo "override MXE_PLUGIN_DIRS += plugins/gcc$MXE_GCC_VERSION" >> settings.mk
+
+fi
+
 #################################################################################################
 # Dependencies build and installation
 
-# Use a more recent gcc version with MXE
-echo -e "\n"
-echo "---------- Building cross-compiler for MXE"
-make MXE_TARGETS=$MXE_BUILD_TARGETS cc MXE_PLUGIN_DIRS="plugins/gcc9" 
-
-echo -e "\n"
-echo "---------- Building digiKam low level dependencies with MXE"
-
-# Switch to a more recent gcc version
-echo 'override MXE_PLUGIN_DIRS += plugins/gcc9' >> settings.mk
-
 make MXE_TARGETS=$MXE_BUILD_TARGETS \
      openssl \
      cmake \
+     yasm \
      gettext \
      freeglut \
      libxml2 \
      libxslt \
      libjpeg-turbo \
      libpng \
+     djvulibre \
      tiff \
      boost \
      expat \
@@ -126,28 +134,45 @@ make MXE_TARGETS=$MXE_BUILD_TARGETS \
      eigen \
      jasper \
      zlib \
+     bzip2 \
      mman-win32 \
      pthreads \
      libgphoto2 \
-     qtbase \
+     icu4c \
+     qtbase qtbase_CONFIGURE_OPTS=-icu \
      qttranslations \
      qtimageformats \
      qttools \
      qtwinextras \
      qtscript \
      qtwebkit \
+     fdk-aac \
+     x264 \
      x265 \
-     ffmpeg \
+     xvidcore \
+     libvpx \
+     theora \
+     vorbis \
+     opencore-amr \
+     librtmp \
+     opus \
+     speex \
+     lame \
+     freetype \
+     libass \
      openal \
      libical \
-     imagemagick
+     fftw \
+     libltdl \
+     openexr
 
 echo -e "\n"
 
+cd $ORIG_WD
 cp -f ../../scripts/create_manifest.sh $MXE_BUILDROOT
 cd $MXE_BUILDROOT
 $MXE_BUILDROOT/create_manifest.sh $MXE_BUILDROOT mxe
-cp $MXE_BUILDROOT/MXE_manifest.txt $ORIG_WD/data/
+cp $MXE_BUILDROOT/mxe_manifest.txt $ORIG_WD/data/
 
 #################################################################################################
 
@@ -168,6 +193,7 @@ rm -rf $BUILDING_DIR/* || true
 ${MXE_BUILD_TARGETS}-cmake $ORIG_WD/../3rdparty \
                            -DMXE_TOOLCHAIN=${MXE_TOOLCHAIN} \
                            -DMXE_BUILDROOT=${MXE_BUILDROOT} \
+                           -DMXE_BUILD_TARGETS=${MXE_BUILD_TARGETS} \
                            -DMXE_ARCHBITS=${MXE_ARCHBITS} \
                            -DMXE_INSTALL_PREFIX=${MXE_INSTALL_PREFIX} \
                            -DCMAKE_BUILD_TYPE=RelWithDebInfo \
@@ -190,8 +216,14 @@ ${MXE_BUILD_TARGETS}-cmake $ORIG_WD/../3rdparty \
 # Low level libraries
 # NOTE: The order to compile each component here is very important.
 
-${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_opencv     -- -j$CPU_CORES
-${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_drmingw    -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libde265    -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libjxl      -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libaom      -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_libavif     -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_ffmpeg      -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_imagemagick -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
+${MXE_BUILD_TARGETS}-cmake --build . --config RelWithDebInfo --target ext_drmingw     -- -j$CPU_CORES
 
 #################################################################################################
 
