@@ -241,10 +241,10 @@ fi
 #################################################################################################
 # Install ExifTool binary.
 
-    cd $DOWNLOAD_DIR
+cd $DOWNLOAD_DIR
 
 if [ ! -f $DOWNLOAD_DIR/exiftool-$DK_EXIFTOOL_VERSION.zip ] ; then
-    wget https://sourceforge.net/projects/exiftool/files/exiftool-$DK_EXIFTOOL_VERSION.zip/download -O exiftool-$DK_EXIFTOOL_VERSION.zip
+    wget https://files.kde.org/digikam/exiftool/exiftool-$DK_EXIFTOOL_VERSION.zip -O exiftool-$DK_EXIFTOOL_VERSION.zip
 fi
 
 unzip -o $DOWNLOAD_DIR/exiftool-$DK_EXIFTOOL_VERSION.zip -d $BUNDLEDIR
@@ -263,6 +263,12 @@ if [[ $DK_VERSION != v* ]] ; then
     # with non-official release version, use build time-stamp as sub-version string.
     DK_SUBVER="-`cat $ORIG_WD/data/BUILDDATE.txt`"
 
+else
+
+    # with official release version, disable upload to KDE server, as this break check for new version function.
+    echo -e "Official release version detected, upload is disabled.\n"
+    DK_UPLOAD = 0
+
 fi
 
 #################################################################################################
